bicycledataprocessor Package
============================

:mod:`database` Module
----------------------

.. automodule:: bicycledataprocessor.database
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`main` Module
---------------------------

.. automodule:: bicycledataprocessor.main
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`signalprocessing` Module
------------------------------

.. automodule:: bicycledataprocessor.signalprocessing
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    bicycledataprocessor.test.rst
